Integer i = 10;
Boolean b;
String args[];
final MyType args[];
final My_Type args[];
List<Integer> mylist;
List<List<Integer> > mylist;
java.io.InputStream iStream ;
if (argc > 0) { }
Boolean 0;
_myClass c;
__myClass c;
__my_Class c;